@@ -20,6 +20,8 @@
 #ifndef DRAGONPLAYER_H
 #define DRAGONPLAYER_H
 
+#include "config.h"
+
 // try to keep this file light. It gets included by
 // practically every implementation and many headers
 
@@ -30,13 +32,13 @@ class QWidget;
 
 namespace Dragon
 {
-        QWidget *mainWindow(); //defined in mainWindow.cpp
+QWidget *mainWindow(); //defined in mainWindow.cpp
 }
 
 /// used by mainWindow.h
 int main( int, char** );
 
-#define APP_VERSION "2.0"
+#define APP_VERSION PROJECT_VERSION
 #define APP_NAME "dragonplayer"
 
 #endif
